@@ -4,7 +4,9 @@ Aggregates events in to the task data model.
 from datetime import datetime
 import logging
 
+from firexkit.task import FIREX_REVOKE_COMPLETE_EVENT_TYPE
 from firexapp.events.model import ADDITIONAL_CHILDREN_KEY, EXTERNAL_COMMANDS_KEY
+from firexapp.events.event_aggregator import event_type_to_task_state, REVOKED_EVENT_TYPE
 
 from firex_flame.flame_helper import deep_merge
 
@@ -12,6 +14,7 @@ logger = logging.getLogger(__name__)
 
 TASK_ARGS = 'firex_bound_args'
 
+
 #
 # config field options:
 #   copy_celery - True if this field should be copied from the celery event to the task data model. If the field already
@@ -42,8 +45,9 @@ FIELD_CONFIG = {
     'type': {
         'copy_celery': True,
         'transform_celery': lambda e: {
-            'state': e['type'],
-            'states': [{'state': e['type'], 'timestamp': e.get('local_received', None)}],
+            'state': event_type_to_task_state(e['type']),
+            'states': [{'state': event_type_to_task_state(e['type']),
+                        'timestamp': e.get('local_received', None)}],
         } if e['type'] in STATE_TYPES else {},
     },
     'retries': {'copy_celery': True, 'slim_field': True},
@@ -131,8 +135,9 @@ STATE_TYPES = {
     'task-unblocked': {'terminal': False},
     'task-succeeded': {'terminal': True},
     'task-failed': {'terminal': True},
-    'task-revoked': {'terminal': True},
+    REVOKED_EVENT_TYPE: {'terminal': True},
     'task-incomplete': {'terminal': True},  # server-side kludge state to fix tasks that will never complete.
+    FIREX_REVOKE_COMPLETE_EVENT_TYPE: {'terminal': True}
 }
 COMPLETE_STATES = [s for s, v in STATE_TYPES.items() if v['terminal']]
 INCOMPLETE_STATES = [s for s, v in STATE_TYPES.items() if not v['terminal']]
